@@ -47,6 +47,9 @@ if(space)
 N=length(fit$data)
 coords=cbind(fit$coordx,fit$coordy)
 data=fit$data
+Mloc=NULL
+if(length(fit$fixed$mean)>1)  tempM=fit$fixed$mean
+if(!is.null(X)) tempX=fit$X
 
 set.seed(round(seed))
 pb <- txtProgressBar(min = 0, max = K, style = 3)
@@ -56,18 +59,24 @@ sel_data = sample(1:N,round(N*(1-n.fold)))
 # data and coord used for prediction
 
 if(!is.null(X)) {
-                X=fit$X[sel_data,]
-                Xloc=fit$X[-sel_data,]
+                X=tempX[sel_data,]
+                Xloc=tempX[-sel_data,]
                 }
-# data and coord to predict
+if(length(fit$fixed$mean)>1)  
+       {    
+            fit$fixed$mean=tempM[sel_data]
+            Mloc=tempM[-sel_data]
+       }
+        
+# data to predict
 data_to_pred  = fit$data[-sel_data]
+#dtp[[i]]=data_to_pred
 
-dtp[[i]]=data_to_pred
 
-#param=as.list(c(fit$param,fit$fixed))
 param=append(fit$param,fit$fixed)
+
 if(estimation) {
-          fit_s= GeoFit2(data=fit$data[sel_data],coordx=coords[sel_data,],corrmodel=fit$corrmodel,X=X,
+          fit_s= GeoFit(data=fit$data[sel_data],coordx=coords[sel_data,],corrmodel=fit$corrmodel,X=X,
                             likelihood=fit$likelihood,type=fit$type,grid=fit$grid,
                             copula=fit$copula,anisopars=fit$anisopars,est.aniso=fit$est.aniso,
                             model=model1,radius=fit$radius,n=fit$n,
@@ -76,29 +85,30 @@ if(estimation) {
                             optimizer=fit$optimizer, lower=fit$lower,upper=fit$upper,
                            start=fit$param,fixed=fit$fixed)
         
-if(!is.null(fit$anisopars))   
-                   {   fit_s$param$angle=NULL;fit_s$param$ratio=NULL; fit_s$fixed$angle=NULL;fit_s$fixed$ratio=NULL}
-
+if(!is.null(fit$anisopars))   {   fit$param$angle=NULL;fit$param$ratio=NULL; fit$fixed$angle=NULL;fit$fixed$ratio=NULL}
             param=append(fit_s$param,fit_s$fixed)
-           
-              }
- 
-if(!local) {pr=GeoKrig(data=fit$data[sel_data], coordx=coords[sel_data,],  
-	            corrmodel=fit$corrmodel, distance=fit$distance,grid=fit$grid,loc=coords[-sel_data,], #ok
-	            model=fit$model, n=fit$n, mse=TRUE,#ok
-              param=param, anisopars=fit_s$anisopars,
-               radius=fit$radius, sparse=sparse, X=X,Xloc=Xloc) #ok
              }
 
-if(local) {pr=GeoKrigloc(data=fit$data[sel_data], coordx=coords[sel_data,],  
+if(!local) { 
+          
+             pr=GeoKrig(data=fit$data[sel_data], coordx=coords[sel_data,],  
+	            corrmodel=fit$corrmodel, distance=fit$distance,grid=fit$grid,loc=coords[-sel_data,], #ok
+	            model=fit$model, n=fit$n, mse=TRUE,#ok
+              param=param, anisopars=fit$anisopars,
+               radius=fit$radius, sparse=sparse, X=X,Xloc=Xloc,Mloc=Mloc) #ok
+           
+             }
+
+if(local) {
+              pr=GeoKrigloc(data=fit$data[sel_data], coordx=coords[sel_data,],  
               corrmodel=fit$corrmodel, distance=fit$distance,grid=fit$grid,loc=coords[-sel_data,], #ok
               model=fit$model, n=fit$n, mse=TRUE,#ok
               neighb=neighb,maxdist=maxdist,
-              param=param, anisopars=fit_s$anisopars,
-              radius=fit$radius, sparse=sparse, X=X,Xloc=Xloc) #ok
+              param=param, anisopars=fit$anisopars,
+              radius=fit$radius, sparse=sparse, X=X,Xloc=Xloc,Mloc=Mloc) #ok
               }
 
-pred[[i]]=as.numeric(pr$pred)
+#pred[[i]]=as.numeric(pr$pred)
 err=data_to_pred-pr$pred  
 
 sqrtvv=sqrt(pr$mse)
@@ -113,107 +123,9 @@ setTxtProgressBar(pb, i)
 i=i+1} ##end while
 close(pb)
 }
-############################################################
-########### spatial bivariate case ###################################
-############################################################
-if(bivariate)
-{
-ns=fit$ns
-if(space_dyn) {data1=fit$data[[1]]
-               data2=fit$data[[2]]
-               coords1=fit$coordx_dyn[[1]]
-               coords2=fit$coordx_dyn[[2]]
-               }
-if(!space_dyn) {data1=fit$data[1,];data2=fit$data[2,]
-                coords=cbind(fit$coordx,fit$coordy)
-                coords1=coords; coords2=coords
-               }
-if(!is.null(X)) {
-                if(!is.list(fit$X)){X1=fit$X[1:ns[1],];X2=fit$X[(ns[1]+1):(ns[1]+ns[2]),]}
-                if( is.list(fit$X)){X1=fit$X[[1]];X2=fit$X[[2]]}
-                }
-set.seed(round(seed))
 
-pb <- txtProgressBar(min = 0, max = K, style = 3)
-#param=as.list(c(fit$param,fit$fixed))
-param=append(fit$param,fit$fixed)
-while(i<=K){
-Sys.sleep(0.1)
-#######################################	
-if(which==1) {
-	          sel_data = sample(1:ns[1],round(ns[1]*(1-n.fold))) 
-              cc1= coords1[sel_data,]
-              loc_to_pred   = coords1[-sel_data,]
-              d1   = data1[sel_data]
-              data_to_pred  = data1[-sel_data]
-              if(!is.null(X)) { X=rbind(X1[sel_data,],X2); Xloc=rbind(X1[-sel_data,],X2)}
-datanew=list();datanew[[1]]=d1;datanew[[2]]=data2;
-coordsnew=list();coordsnew[[1]]=cc1;coordsnew[[2]]=coords2;
-          }
-if(which==2) {
-	          sel_data = sample(1:ns[2],round(ns[2]*(1-n.fold))) 
-              cc2= coords2[sel_data,]
-              loc_to_pred   = coords2[-sel_data,]
-              d2   = data2[sel_data]
-              data_to_pred  = data2[-sel_data]
-              if(!is.null(X)) {X=rbind(X1,X2[sel_data,]); Xloc=rbind(X1,X2[-sel_data,])}
-datanew=list();datanew[[1]]=data1;datanew[[2]]=d2;
-coordsnew=list();coordsnew[[1]]=coords1;coordsnew[[2]]=cc2;
-            }
-dtp[[i]]=data_to_pred
 
-if(estimation) {
-          fit_s= GeoFit(data=fit$data[sel_data],coordx=coords[sel_data,],corrmodel=fit$corrmodel,X=X,
-                            likelihood=fit$likelihood,c,type=fit$type,grid=fit$grid,
-                            model=model1,radius=fit$radius,n=fit$n,
-                               copula=fit$copula,
-                             local=fit$local,GPU=fit$GPU,
-                           maxdist=fit$maxdist, neighb=fit$neighb,distance=fit$distance,
-                            optimizer=fit$optimizer, lower=fit$lower,upper=fit$upper,
-                           # start=as.list(fit$param),fixed=as.list(fit$fixed))
-                               start=fit$param,fixed=fit$fixed)
 
-             if(!is.null(fit$anisopars))   
-                   {   fit_s$param$angle=NULL;fit_s$param$ratio=NULL;
-                       fit_s$fixed$angle=NULL;fit_s$fixed$ratio=NULL
-                        }
-
-            param=append(fit_s$param,fit_s$fixed)
-              }
-#####################################
-if(!local) pr=GeoKrig(data=datanew, coordx=NULL,   coordt=NULL, coordx_dyn=coordsnew,  #ok
-	       corrmodel=fit$corrmodel, distance=fit$distance,grid=fit$grid,loc=loc_to_pred, #ok
-	          model=fit$model, n=fit$n, mse=TRUE,#ok
-           param=param, 
-           radius=fit$radius, sparse=sparse,   time=NULL, 
-             which=which, X=X,Xloc=Xloc) #ok  
-
-if(local) pr=GeoKrigloc(data=datanew, coordx=NULL,   coordt=NULL, coordx_dyn=coordsnew,  #ok
-         corrmodel=fit$corrmodel, distance=fit$distance,grid=fit$grid,loc=loc_to_pred, #ok
-            model=fit$model, n=fit$n, mse=TRUE,#ok
-           neighb=neighb, maxdist=maxdist,
-           param=param, 
-           radius=fit$radius, sparse=sparse,   time=NULL, 
-             which=which, X=X,Xloc=Xloc) #ok  
-
-pred[[i]]=as.numeric(pr$pred)
-err=data_to_pred-pr$pred  
-
-sqrtvv=sqrt(pr$mse)
-std=err/sqrtvv
-
-   
-N2=length(err)
-rmse=c(rmse,sqrt(sum(err^2)/N2))
-mae= c(mae,      sum(abs(err))/N2)
-lscore=c(lscore, 0.5*sum(std^2+log(2*pi*sqrtvv))/N2 )
-crps=c(crps,sum( sqrtvv*( std*(2*pnorm(std)-1 ) +2*pnorm(std)-1/sqrt(pi)))/N2)
-
-i=i+1
-setTxtProgressBar(pb, i)
-}               
-close(pb) 
-} ## end bivariate
 ############################################################
 ########### spatio temporal case ###########################
 ############################################################
@@ -282,11 +194,11 @@ if(ncol(Xnew[[1]])==1) Xnew=NULL
 param=append(fit$param,fit$fixed)
 if(estimation) {
 
-           fit_s= GeoFit2(data=datanew,coordx_dyn=coordx_dynnew,coordt=utt,
+           fit_s= GeoFit(data=datanew,coordx_dyn=coordx_dynnew,coordt=utt,
                             corrmodel=fit$corrmodel,X=Xnew,
                             likelihood=fit$likelihood,type=fit$type,grid=fit$grid,
                             copula=fit$copula, #anisopars=fit$anisopars,#est.aniso=fit$est.aniso,
-                            model="Gaussian",radius=fit$radius,n=fit$n,
+                            model=model1,radius=fit$radius,n=fit$n,
                             local=fit$local,GPU=fit$GPU,
                             maxdist=fit$maxdist, neighb=fit$neighb,maxtime=fit$maxtime,distance=fit$distance,
                             optimizer=fit$optimizer, lower=fit$lower,upper=fit$upper,
@@ -300,6 +212,7 @@ if(estimation) {
 
 #####################################
 if(!local) {
+
            pr_st=pr_mse=list()
            for(j in 1:length(utt_1) ){
             if(is.null(Xnew)) {Xnew_loc[j]=list(NULL)}
@@ -311,17 +224,15 @@ if(!local) {
          }
  }
 if(local) {
+     
            pr_st=pr_mse=list()
            for(j in 1:length(utt_1) ){
             if(is.null(Xnew)) {Xnew_loc[j]=list(NULL)}
-          
                pr=GeoKrigloc(data=datanew,   coordt=utt, coordx_dyn=coordx_dynnew,  #ok
                    corrmodel=fit$corrmodel, distance=fit$distance,grid=fit$grid,loc=coordx_dynnew_loc[[j]], #ok
                    model=fit$model, n=fit$n,  param=param, radius=fit$radius,   time=utt_1[j], mse=TRUE,
                    neighb=neighb,maxdist=maxdist,maxtime=maxtime,
                    X=Xnew,Xloc=Xnew_loc[[j]]) #ok  
-
-  
                 pr_st[[j]]=pr$pred ; pr_mse[[j]]=pr$mse
                    }
 }   
@@ -347,5 +258,117 @@ dtp=dd_to_pred
 pred=pr_st
 } ## end spacetime
 
+
+
+
+############################################################
+########### spatial bivariate case ###################################
+############################################################
+if(bivariate)
+{
+ns=fit$ns
+if(space_dyn) {data1=fit$data[[1]]
+               data2=fit$data[[2]]
+               coords1=fit$coordx_dyn[[1]]
+               coords2=fit$coordx_dyn[[2]]
+               }
+if(!space_dyn) {data1=fit$data[1,];data2=fit$data[2,]
+                coords=cbind(fit$coordx,fit$coordy)
+                coords1=coords; coords2=coords
+               }
+if(!is.null(X)) {
+                if(!is.list(fit$X)){X1=fit$X[1:ns[1],];X2=fit$X[(ns[1]+1):(ns[1]+ns[2]),]}
+                if( is.list(fit$X)){X1=fit$X[[1]];X2=fit$X[[2]]}
+                }
+set.seed(round(seed))
+
+pb <- txtProgressBar(min = 0, max = K, style = 3)
+#param=as.list(c(fit$param,fit$fixed))
+param=append(fit$param,fit$fixed)
+while(i<=K){
+Sys.sleep(0.1)
+#######################################	
+if(which==1) {
+	          sel_data = sample(1:ns[1],round(ns[1]*(1-n.fold))) 
+              cc1= coords1[sel_data,]
+              loc_to_pred   = coords1[-sel_data,]
+              d1   = data1[sel_data]
+              data_to_pred  = data1[-sel_data]
+              if(!is.null(X)) { X=rbind(X1[sel_data,],X2); Xloc=rbind(X1[-sel_data,],X2)}
+datanew=list();datanew[[1]]=d1;datanew[[2]]=data2;
+coordsnew=list();coordsnew[[1]]=cc1;coordsnew[[2]]=coords2;
+          }
+if(which==2) {
+	          sel_data = sample(1:ns[2],round(ns[2]*(1-n.fold))) 
+              cc2= coords2[sel_data,]
+              loc_to_pred   = coords2[-sel_data,]
+              d2   = data2[sel_data]
+              data_to_pred  = data2[-sel_data]
+              if(!is.null(X)) {X=rbind(X1,X2[sel_data,]); Xloc=rbind(X1,X2[-sel_data,])}
+datanew=list();datanew[[1]]=data1;datanew[[2]]=d2;
+coordsnew=list();coordsnew[[1]]=coords1;coordsnew[[2]]=cc2;
+            }
+dtp[[i]]=data_to_pred
+
+if(estimation) {
+          fit_s= GeoFit(data=fit$data[sel_data],coordx=coords[sel_data,],corrmodel=fit$corrmodel,X=X,
+                            likelihood=fit$likelihood,c,type=fit$type,grid=fit$grid,
+                            model="Gaussian",radius=fit$radius,n=fit$n,
+                               copula=fit$copula,
+                             local=fit$local,GPU=fit$GPU,
+                           maxdist=fit$maxdist, neighb=fit$neighb,distance=fit$distance,
+                            optimizer=fit$optimizer, lower=fit$lower,upper=fit$upper,
+                           # start=as.list(fit$param),fixed=as.list(fit$fixed))
+                               start=fit$param,fixed=fit$fixed)
+
+             if(!is.null(fit$anisopars))   
+                   {   fit_s$param$angle=NULL;fit_s$param$ratio=NULL;
+                       fit_s$fixed$angle=NULL;fit_s$fixed$ratio=NULL
+                        }
+
+            param=append(fit_s$param,fit_s$fixed)
+              }
+#####################################
+if(!local) 
+    {
+        
+        pr=GeoKrig(data=datanew, coordx=NULL,   coordt=NULL, coordx_dyn=coordsnew,  #ok
+	       corrmodel=fit$corrmodel, distance=fit$distance,grid=fit$grid,loc=loc_to_pred, #ok
+	          model=fit$model, n=fit$n, mse=TRUE,#ok
+           param=param, 
+           radius=fit$radius, sparse=sparse,   time=NULL, 
+             which=which, X=X,Xloc=Xloc,Mloc=Mloc) 
+    }#ok  
+
+if(local) 
+   {
+          pr=GeoKrigloc(data=datanew, coordx=NULL,   coordt=NULL, coordx_dyn=coordsnew,  #ok
+         corrmodel=fit$corrmodel, distance=fit$distance,grid=fit$grid,loc=loc_to_pred, #ok
+            model=fit$model, n=fit$n, mse=TRUE,#ok
+           neighb=neighb, maxdist=maxdist,
+           param=param, 
+           radius=fit$radius, sparse=sparse,   time=NULL, 
+             which=which, X=X,Xloc=Xloc,Mloc=Mloc) #ok  
+   }   
+
+#pred[[i]]=as.numeric(pr$pred)
+err=data_to_pred-pr$pred  
+
+sqrtvv=sqrt(pr$mse)
+std=err/sqrtvv
+
+   
+N2=length(err)
+rmse=c(rmse,sqrt(sum(err^2)/N2))
+mae= c(mae,      sum(abs(err))/N2)
+lscore=c(lscore, 0.5*sum(std^2+log(2*pi*sqrtvv))/N2 )
+crps=c(crps,sum( sqrtvv*( std*(2*pnorm(std)-1 ) +2*pnorm(std)-1/sqrt(pi)))/N2)
+
+i=i+1
+setTxtProgressBar(pb, i)
+}               
+close(pb) 
+} ## end bivariate
+
 return(list(rmse=rmse,mae=mae,crps=crps,lscore=lscore,predicted=pred,data_to_pred=dtp))
 }
